@@ -1,6 +1,6 @@
-package HTTP::Throwable::Factory;
+package HTTP::Throwable::Factory 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Factory::VERSION = '0.027';
+
 use strict;
 use warnings;
 
@@ -126,7 +126,7 @@ my %lookup = (
     500 => 'InternalServerError',
     501 => 'NotImplemented',
     502 => 'BadGateway',
-    503 => 'Status::ServiceUnavailable',
+    503 => 'ServiceUnavailable',
     504 => 'GatewayTimeout',
     505 => 'HTTPVersionNotSupported',
 );
@@ -150,7 +150,7 @@ HTTP::Throwable::Factory - a factory that throws HTTP::Throwables for you
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 OVERVIEW
 
@@ -201,6 +201,16 @@ called as methods.  For example:
       mount '/old' => http_exception('Gone'),
   };
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 SUBCLASSING
 
 One of the big benefits of using HTTP::Throwable::Factory is that you can
@@ -262,7 +272,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
