@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Redirect;
+package HTTP::Throwable::Role::Redirect 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Redirect::VERSION = '0.027';
+
 use Types::Standard qw(Str);
 
 use Moo::Role;
@@ -32,7 +32,7 @@ HTTP::Throwable::Role::Redirect - an exception that is a redirect
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 OVERVIEW
 
@@ -44,6 +44,16 @@ Note that "MultipleChoices," the 300 status code is I<not> currently a
 redirect, as its Location header is optional.  This may change in the future of
 the semantics of this role are refined.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -54,7 +64,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
