@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::ImATeapot;
+package HTTP::Throwable::Role::Status::ImATeapot 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::ImATeapot::VERSION = '0.027';
+
 use Types::Standard qw(Bool);
 
 use Moo::Role;
@@ -54,7 +54,7 @@ HTTP::Throwable::Role::Status::ImATeapot - 418 I'm a teapot
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -65,6 +65,16 @@ This exception provides RFC2324 support, in accordance with section 2.3.3:
 
 Boolean attributes C<short> and C<stout> are provided, and default to false.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -75,7 +85,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
