@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::InternalServerError;
+package HTTP::Throwable::Role::Status::InternalServerError 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::InternalServerError::VERSION = '0.027';
+
 use Types::Standard qw(Bool);
 
 use Moo::Role;
@@ -37,13 +37,23 @@ HTTP::Throwable::Role::Status::InternalServerError - 500 Internal Server Error
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
 The server encountered an unexpected condition which prevented it
 from fulfilling the request.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 show_stack_trace
@@ -62,7 +72,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
