@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::MovedPermanently;
+package HTTP::Throwable::Role::Status::MovedPermanently 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::MovedPermanently::VERSION = '0.027';
+
 use Moo::Role;
 
 with(
@@ -24,7 +24,7 @@ HTTP::Throwable::Role::Status::MovedPermanently - 301 Moved Permanently
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -40,6 +40,16 @@ response. Unless the request method was HEAD, the entity of the
 response SHOULD contain a short hypertext note with a hyperlink to
 the new URI(s).
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -50,7 +60,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
