@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::NotModified;
+package HTTP::Throwable::Role::Status::NotModified 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::NotModified::VERSION = '0.027';
+
 use Moo::Role;
 
 use Plack::Util ();
@@ -39,7 +39,7 @@ HTTP::Throwable::Role::Status::NotModified - 304 Not Modified
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -80,6 +80,16 @@ If a cache uses a received 304 response to update a cache entry,
 the cache MUST update the entry to reflect any new field values
 given in the response.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -90,7 +100,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
