@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::ProxyAuthenticationRequired;
+package HTTP::Throwable::Role::Status::ProxyAuthenticationRequired 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::ProxyAuthenticationRequired::VERSION = '0.027';
+
 use Types::Standard qw(Str ArrayRef);
 
 use Moo::Role;
@@ -45,7 +45,7 @@ HTTP::Throwable::Role::Status::ProxyAuthenticationRequired - 407 Proxy Authentic
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,16 @@ return a Proxy-Authenticate header field containing a challenge applicable
 to the proxy for the requested resource. The client MAY repeat the request
 with a suitable Proxy-Authorization header field.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 proxy_authenticate
@@ -78,7 +88,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
