@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable;
+package HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable::VERSION = '0.027';
+
 use Types::Standard qw(Str);
 
 use Moo::Role;
@@ -37,7 +37,7 @@ HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable - 416 Requested Rang
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -54,6 +54,16 @@ response SHOULD include a Content-Range entity-header field specifying
 the current length of the selected resource. This response MUST NOT
 use the multipart/byteranges content-type.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -64,7 +74,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
