@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::SeeOther;
+package HTTP::Throwable::Role::Status::SeeOther 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::SeeOther::VERSION = '0.027';
+
 use Moo::Role;
 
 with(
@@ -24,7 +24,7 @@ HTTP::Throwable::Role::Status::SeeOther - 303 See Other
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -42,6 +42,16 @@ the response. Unless the request method was HEAD, the entity
 of the response SHOULD contain a short hypertext note with a
 hyperlink to the new URI(s).
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -52,7 +62,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
