@@ -1,6 +1,6 @@
-package HTTP::Throwable::Variant;
+package HTTP::Throwable::Variant 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Variant::VERSION = '0.027';
+
 use strict;
 use warnings;
 
@@ -27,7 +27,7 @@ HTTP::Throwable::Variant - a package that constructs Moo-based HTTP::Throwables
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 OVERVIEW
 
@@ -37,6 +37,16 @@ L<MooX::StrictConstructor> applied as well.  It takes two arguments:
 C<superclasses>, an arrayref of classes to extend, and C<roles>, an
 arrayref of roles to compose.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -47,7 +57,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
